@@ -683,9 +683,15 @@ draw_action_custom (GsdOsdDrawContext  *ctx,
         bright_box_height = round (window_height * 0.05);
 
         icon_box_x0 = round ((window_width - icon_box_width) / 2);
-        icon_box_y0 = round ((window_height - icon_box_height - bright_box_height) / 2 - bright_box_height);
-        bright_box_x0 = round (icon_box_x0);
-        bright_box_y0 = round (icon_box_height + icon_box_y0) + bright_box_height;
+        if (ctx->show_level != FALSE) {
+                icon_box_y0 = round ((window_height - icon_box_height - bright_box_height) / 2 - bright_box_height);
+                bright_box_x0 = round (icon_box_x0);
+                bright_box_y0 = round (icon_box_height + icon_box_y0) + bright_box_height;
+        } else {
+                icon_box_y0 = round ((window_height - icon_box_height) / 2);
+                bright_box_x0 = 0;
+                bright_box_y0 = 0;
+        }
 
 #if 0
         g_message ("icon box: w=%f h=%f _x0=%f _y0=%f",
